# wrk-platform-sdk
The Wrk API is organized around REST. Our API has predictable resource-oriented URLs, accepts and returns JSON-encoded requests and responses. It uses standard HTTP response codes, authentication, and verbs.

Please note you need will an API key with the appropriate access to use the following APIs. The API key can be obtained from [this page](https://account.wrk.com/api-key) in your Wrk account. To elevate access to your account, please [contact your Sales team](https://www.wrk.com/meet-automation-expert).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.2.0
- Package version: 3.2.0
- Generator version: 7.13.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import wrk_platform_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import wrk_platform_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import wrk_platform_sdk
from wrk_platform_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://account.wrk.com/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = wrk_platform_sdk.Configuration(
    host = "https://account.wrk.com/api/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with wrk_platform_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = wrk_platform_sdk.ConnectedAccountsApi(api_client)
    create_connected_account_request = wrk_platform_sdk.CreateConnectedAccountRequest() # CreateConnectedAccountRequest | Create a new Connected Account by providing the Connected Account details (optional)

    try:
        # Create Connected Account
        api_response = api_instance.create_connected_account(create_connected_account_request=create_connected_account_request)
        print("The response of ConnectedAccountsApi->create_connected_account:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ConnectedAccountsApi->create_connected_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://account.wrk.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ConnectedAccountsApi* | [**create_connected_account**](docs/ConnectedAccountsApi.md#create_connected_account) | **POST** /connected-account | Create Connected Account
*ConnectedAccountsApi* | [**get_connected_account**](docs/ConnectedAccountsApi.md#get_connected_account) | **GET** /connected-account/{connected_account_id} | Fetch Connected Account
*ConnectedAccountsApi* | [**get_connected_accounts**](docs/ConnectedAccountsApi.md#get_connected_accounts) | **GET** /connected-account | Fetch Connected Accounts
*ConnectedAccountsApi* | [**update_connected_account**](docs/ConnectedAccountsApi.md#update_connected_account) | **PUT** /connected-account/{connected_account_id} | Update Connected Account
*LaunchActivitiesApi* | [**get_launch_activities**](docs/LaunchActivitiesApi.md#get_launch_activities) | **GET** /launch/{launch_id}/activity | Get Wrkflow Launch Activities
*LaunchesApi* | [**get_launch_by_id**](docs/LaunchesApi.md#get_launch_by_id) | **GET** /launch/{launch_id} | Fetch a specific Wrkflow Launch
*LaunchesApi* | [**get_launches**](docs/LaunchesApi.md#get_launches) | **GET** /launch | Fetch multiple Wrkflow Launches
*LaunchesApi* | [**launch_wrkflow**](docs/LaunchesApi.md#launch_wrkflow) | **POST** /wrkflow/{wrkflow_uuid}/launch | Launch a Wrkflow
*LaunchesApi* | [**launch_wrkflow_sync**](docs/LaunchesApi.md#launch_wrkflow_sync) | **POST** /wrkflow/{wrkflow_uuid}/launch-sync | Launches the wrkflow via a POST request and returns the result of the wrkflow, or a default response if no results were produced within the specified timeout.
*LaunchesApi* | [**pause_launch**](docs/LaunchesApi.md#pause_launch) | **POST** /launch/{launch_id}/pause | Pause a Wrkflow Launch
*LaunchesApi* | [**resume_launch**](docs/LaunchesApi.md#resume_launch) | **POST** /launch/{launch_id}/resume | Resume a Wrkflow Launch
*WebhooksApi* | [**execute_webhook_sync**](docs/WebhooksApi.md#execute_webhook_sync) | **POST** /webhook/{webhook_uuid}/execute-sync | Executes a previously-configured webhook via a POST request and returns the result of the execution, or a default response if no results were produced within the specified timeout.
*WrkActionResourcesApi* | [**get_action_applications**](docs/WrkActionResourcesApi.md#get_action_applications) | **GET** /action-application | Fetch Action Applications
*WrkActionResourcesApi* | [**get_credentials**](docs/WrkActionResourcesApi.md#get_credentials) | **GET** /credential | Fetch Credentials
*WrkActionResourcesApi* | [**get_outcomes**](docs/WrkActionResourcesApi.md#get_outcomes) | **GET** /outcome | Fetch Outcomes
*WrkActionResourcesApi* | [**get_wrk_actions**](docs/WrkActionResourcesApi.md#get_wrk_actions) | **GET** /wrk-action | Fetch Wrk Actions
*WrkflowsApi* | [**create_wrkflow**](docs/WrkflowsApi.md#create_wrkflow) | **POST** /wrkflow | Create or update a Wrkflow
*WrkflowsApi* | [**get_wrkflow_by_uuid**](docs/WrkflowsApi.md#get_wrkflow_by_uuid) | **GET** /wrkflow/{wrkflow_uuid} | Fetch a specific Wrkflow
*WrkflowsApi* | [**get_wrkflows**](docs/WrkflowsApi.md#get_wrkflows) | **GET** /wrkflow | Fetch multiple Wrkflows


## Documentation For Models

 - [ActionApplication](docs/ActionApplication.md)
 - [ActionApplicationSpec](docs/ActionApplicationSpec.md)
 - [ConnectedAccount](docs/ConnectedAccount.md)
 - [CreateConnectedAccountAcceptedResponse](docs/CreateConnectedAccountAcceptedResponse.md)
 - [CreateConnectedAccountCreatedResponse](docs/CreateConnectedAccountCreatedResponse.md)
 - [CreateConnectedAccountRequest](docs/CreateConnectedAccountRequest.md)
 - [CreateWrkflowResponse](docs/CreateWrkflowResponse.md)
 - [Credential](docs/Credential.md)
 - [CredentialSpec](docs/CredentialSpec.md)
 - [GetActionApplicationsResponse](docs/GetActionApplicationsResponse.md)
 - [GetConnectedAccountResponse](docs/GetConnectedAccountResponse.md)
 - [GetConnectedAccountsResponse](docs/GetConnectedAccountsResponse.md)
 - [GetCredentialsResponse](docs/GetCredentialsResponse.md)
 - [GetLaunchActivitiesResponse](docs/GetLaunchActivitiesResponse.md)
 - [GetLaunchByIdResponse](docs/GetLaunchByIdResponse.md)
 - [GetLaunchesResponse](docs/GetLaunchesResponse.md)
 - [GetOutcomesResponse](docs/GetOutcomesResponse.md)
 - [GetWrkActionsResponse](docs/GetWrkActionsResponse.md)
 - [GetWrkflowByUuidResponse](docs/GetWrkflowByUuidResponse.md)
 - [GetWrkflowsResponse](docs/GetWrkflowsResponse.md)
 - [Launch](docs/Launch.md)
 - [LaunchActivity](docs/LaunchActivity.md)
 - [LaunchActivityAttachmentsInner](docs/LaunchActivityAttachmentsInner.md)
 - [LaunchPriority](docs/LaunchPriority.md)
 - [LaunchState](docs/LaunchState.md)
 - [LaunchStatus](docs/LaunchStatus.md)
 - [LaunchWrkflowRequest](docs/LaunchWrkflowRequest.md)
 - [LaunchWrkflowResponse](docs/LaunchWrkflowResponse.md)
 - [LaunchWrkflowSync202Response](docs/LaunchWrkflowSync202Response.md)
 - [Outcome](docs/Outcome.md)
 - [OutcomeSpec](docs/OutcomeSpec.md)
 - [UpdateConnectedAccountRequest](docs/UpdateConnectedAccountRequest.md)
 - [WrkAction](docs/WrkAction.md)
 - [WrkActionDefinition](docs/WrkActionDefinition.md)
 - [WrkActionLink](docs/WrkActionLink.md)
 - [WrkActionResourceMetadata](docs/WrkActionResourceMetadata.md)
 - [WrkActionResourceReference](docs/WrkActionResourceReference.md)
 - [WrkActionSpec](docs/WrkActionSpec.md)
 - [WrkActionSpecCost](docs/WrkActionSpecCost.md)
 - [WrkError](docs/WrkError.md)
 - [WrkErrorDetails](docs/WrkErrorDetails.md)
 - [Wrkflow](docs/Wrkflow.md)
 - [WrkflowDefinition](docs/WrkflowDefinition.md)
 - [WrkflowSchedule](docs/WrkflowSchedule.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@wrk.com
